@@ -18,20 +18,17 @@ our @ISA = qw(Exporter);
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 our %EXPORT_TAGS = ( 'all' => [ qw(
-	systee
-    syssplice
-    syssendfile
-    SPLICE_F_MOVE
-    SPLICE_F_NONBLOCK
-    SPLICE_F_MORE
-    SPLICE_F_GIFT
+	
 ) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our @EXPORT = qw();
+our @EXPORT = qw(
+    systee
+    syssplice
+);
 
-our $VERSION = '0.04_01';
+our $VERSION = '0.01';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -72,15 +69,14 @@ Linux::PipeMagic - Perl extension to use the zero copy IO syscalls
 
 =head1 SYNOPSIS
 
-  use Linux::PipeMagic qw/ systee syssplice syssendfile /;
+  use Linux::PipeMagic qw/ systee syssplice /;
   systee($fh_in, $fh_out, $num_bytes, 0);
   syssplice($fh_in, $fh_out, $num_bytes, 0);
-  syssendfile($fh_out, $fh_in, $num_bytes);
 
 =head1 DESCRIPTION
 
-Linux::PipeMagic is a Perl XS wrapper around the L<splice(2)>, L<tee(2)> and L<sendfile(2)>
-syscalls.  You can use them to efficiently copy data from one file descriptor to
+Linux::PipeMagic is a Perl XS wrapper around the L<splice(2)> and L<tee(2)>
+syscalls.  You can use them to efficiently data from one file descriptor to
 another inside the kernel (splice), or to efficiently copy data from one pipe
 to another (tee).
 
@@ -90,29 +86,12 @@ to another (tee).
 
 =item sysplice($fh_in, $fh_out, $num_bytes, $flags)
 
-Copies C<$num_bytes> from C<$fh_in> to C<$fh_out>.  This is roughly equivalent to,
-
-    sysread($fh_in, my $buf, $num_bytes);
-    syswrite($fh_out, $buf);
-
-although the transfer takes place entirely in kernel space.
-
-Returns the number of bytes transferred.
+Moves C<$num_bytes> from C<$fh_in> to C<$fh_out>.
 
 =item systee($fh_in, $fh_out, $num_bytes, $flags)
 
 Copies C<$num_bytes> from C<$fh_in> to C<$fh_out>.  The filehandles must both
-be of type pipe.  This works similarly like C<syssplice> but does not advance the
-read pointer in C<$fh_in>.
-
-Returns the number of bytes transferred.
-
-=item syssendfile($fh_out, $fh_in, $num_bytes)
-
-Copies C<$num_bytes> from C<$fh_in> to C<$fh_out>.  With current versions of
-Linux, C<$fh_in> must be a file opened for reading, and C<$fh_out> must be a
-writable socket.  Note the different order of parameters compared to the other
-functions.
+be of pipes.
 
 =back
 
@@ -154,9 +133,6 @@ L<splice(2)>
 =item *
 L<tee(2)>
 
-=item *
-L<sendfile(2)>
-
 =back
 
 =head1 AUTHOR
@@ -165,7 +141,7 @@ Dave Lambley, E<lt>cpan@davel.org.ukE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011, 2012 by Dave Lambley
+Copyright (C) 2011 by Dave Lambley
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
